﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CsFileCopy
{
    /// <summary>
    /// お気に入りの編集を行うダイアログです。
    /// </summary>
    public partial class EditFavoriteDialog : Form
    {
        /// <summary>
        /// お気に入りのID
        /// </summary>
        public int Id
        {
            get;
            set;
        }

        /// <summary>
        /// お気に入りのタイトル
        /// </summary>
        public string Tile
        {
            set
            {
                titleBox.Text = value;
            }
        }

        /// <summary>
        /// 抽出元フォルダー
        /// </summary>
        public string SourceFolder
        {
            set
            {
                extractFolderBox.Text = value;
            }
        }

        /// <summary>
        /// 抽出対象ファイル
        /// </summary>
        public string ExtractFile
        {
            set
            {
                extractFileBox.Text = value;
            }
        }

        /// <summary>
        /// 抽出除外ファイル
        /// </summary>
        public string ExcludeFile
        {
            set
            {
                excludeFileBox.Text = value;
            }
        }

        /// <summary>
        /// 抽出先フォルダー
        /// </summary>
        public string DestinationFolder
        {
            set
            {
                destinationFolderBox.Text = value;
            }
        }

        public EditFavoriteDialog()
        {
            InitializeComponent();
        }

        /// <summary>
        /// お気に入りの編集画面ロード時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void EditFavoriteDialog_Load(object sender, EventArgs e)
        {
        }

        /// <summary>
        /// お気に入りの編集画面表示時の処理です。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void EditFavoriteDialog_Shown(object sender, EventArgs e)
        {
            titleBox.SelectionLength = 0;
        }

        /// <summary>
        /// キャンセルボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }

        /// <summary>
        /// 保存ボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void saveButton_Click(object sender, EventArgs e)
        {
            if (titleBox.Text.Trim().Length == 0)
            {
                MessageUtil.ShowAlert("タイトルを入力してください。");
                return;
            }

            if (extractFolderBox.Text.Trim().Length == 0
                && extractFileBox.Text.Trim().Length == 0
                && excludeFileBox.Text.Trim().Length == 0
                && destinationFolderBox.Text.Trim().Length == 0)
            {
                MessageUtil.ShowAlert("抽出元フォルダー、抽出対象ファイル、抽出除外ファイル、抽出先フォルダーのいずれか1つは入力してください。");
                return;
            }

            Favorites favorites = new Favorites();

            FavoriteData favorite = new FavoriteData();

            favorite.Id = this.Id;
            favorite.Title = titleBox.Text;
            favorite.ExtractFolder = extractFolderBox.Text;
            favorite.ExtractFile = extractFileBox.Text;
            favorite.ExcludeFile = excludeFileBox.Text;
            favorite.DestinationFolder = destinationFolderBox.Text;

            favorites.UpdateFavorite(favorite);

            MessageUtil.ShowInfo("お気に入りを1件更新しました。");

            DialogResult = DialogResult.OK;
            Close();
        }
    }
}
