﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;

namespace CsFileCopy
{
    /// <summary>
    /// オペレーティングシステムが提供するファイル名のパターン文字列を正規表現に変換するクラスです。
    /// </summary>
    public class REConverter
    {
        /// <summary>
        /// オペレーティングシステムが提供するファイル名のパターン文字列を正規表現に変換して返します。
        /// </summary>
        /// <param name="ospath">オペレーティングシステム標準のファイル名パターン文字列</param>
        /// <returns>正規表現に変換されたファイル名パターン文字列</returns>
        public static string GetRegularExpression(string ospath)
        {
            string result = ospath;

            // 正規表現の特殊文字列をエスケープ
            result = result.Replace("\\", "\\\\");
            result = result.Replace(".", "\\.");
            result = result.Replace("[", "\\[");
            result = result.Replace("]", "\\]");
            result = result.Replace("^", "\\^");
            result = result.Replace("$", "\\$");
            result = result.Replace("(", "\\(");
            result = result.Replace(")", "\\)");
            result = result.Replace("+", "\\+");

            // ワイルドカード文字を正規表現に変換
            result = result.Replace("*", ".*");
            result = result.Replace("?", ".");

            try
            {
                Regex regex = new Regex(result);
            }
            catch (Exception e)
            {
                MessageUtil.ShowAlert("ファイル名を正規表現に変換できませんでした。\n" + e.Message);
            }

            return result;
        }
    }
}
