﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CsFileCopy
{
    /// <summary>
    /// お気に入りの読み込みを行うダイアログです。
    /// </summary>
    public partial class ReadFavoriteDialog : Form
    {
        /// <summary>
        /// メイン画面
        /// </summary>
        MainWindow parent;

        public ReadFavoriteDialog(MainWindow main)
        {
            InitializeComponent();
            this.parent = main;
        }

        /// <summary>
        /// 閉じるボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void closeButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        /// <summary>
        /// お気に入りの読み込み画面ロード時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void ReadFavoriteDialog_Load(object sender, EventArgs e)
        {
            Favorites favorites = new Favorites();

            LoadFavorites(favorites);
        }

        /// <summary>
        /// お気に入りデータをロードします。
        /// </summary>
        /// <param name="favorites">お気に入りデータ管理オブジェクト</param>
        private void LoadFavorites(Favorites favorites)
        {
            favoriteListBox.Items.Clear();

            titleBox.Text = "";
            extractFolderBox.Text = "";
            extractFileBox.Text = "";
            excludeFileBox.Text = "";
            destinationFolderBox.Text = "";

            if (favorites.LoadFavorites() && favorites.FavoritesData.Count > 0)
            {
                favorites.FavoritesData.Sort((a, b) => b.Id - a.Id);

                favorites.FavoritesData.ForEach((FavoriteData favorite) =>
                {
                    favoriteListBox.Items.Add(favorite);
                });

                favoriteListBox.SelectedIndex = 0;

                titleBox.Text = favorites.FavoritesData[0].Title;
                extractFolderBox.Text = favorites.FavoritesData[0].ExtractFolder;
                extractFileBox.Text = favorites.FavoritesData[0].ExtractFile;
                excludeFileBox.Text = favorites.FavoritesData[0].ExcludeFile;
                destinationFolderBox.Text = favorites.FavoritesData[0].DestinationFolder;
            }
        }

        /// <summary>
        /// お気に入り一覧の選択内容が変更された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void favoriteListBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            FavoriteData favorite = (FavoriteData)favoriteListBox.Items[favoriteListBox.SelectedIndex];

            titleBox.Text = favorite.Title;
            extractFolderBox.Text = favorite.ExtractFolder;
            extractFileBox.Text = favorite.ExtractFile;
            excludeFileBox.Text = favorite.ExcludeFile;
            destinationFolderBox.Text = favorite.DestinationFolder;
        }

        /// <summary>
        /// 読み込みボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void readButton_Click(object sender, EventArgs e)
        {
            if (favoriteListBox.Items.Count > 0)
            {
                FavoriteData favorite = (FavoriteData)favoriteListBox.Items[favoriteListBox.SelectedIndex];
                parent.SetFavoriteData(favorite);
                Close();
            }
        }

        /// <summary>
        /// 削除ボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void deleteButton_Click(object sender, EventArgs e)
        {
            if (favoriteListBox.Items.Count == 0)
            {
                return;
            }

            FavoriteData favorite = (FavoriteData)favoriteListBox.Items[favoriteListBox.SelectedIndex];

            if (MessageUtil.ShowQuestion("「" + favorite.Title + "」を削除してもよろしいですか？") == DialogResult.Yes)
            {
                Favorites favorites = new Favorites();
                favorites.DeleteFavorite(favorite);

                MessageUtil.ShowInfo("お気に入りを1件削除しました。");

                LoadFavorites(favorites);
            }
        }

        /// <summary>
        /// タイトルの編集ボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void editButton_Click(object sender, EventArgs e)
        {
            if (favoriteListBox.Items.Count == 0)
            {
                return;
            }

            int selectedIndex = favoriteListBox.SelectedIndex;

            FavoriteData favorite = (FavoriteData)favoriteListBox.Items[selectedIndex];

            EditFavoriteDialog dialog = new EditFavoriteDialog();

            dialog.Id = favorite.Id;
            dialog.Tile = favorite.Title;
            dialog.SourceFolder = favorite.ExtractFolder;
            dialog.ExtractFile = favorite.ExtractFile;
            dialog.ExcludeFile = favorite.ExcludeFile;
            dialog.DestinationFolder = favorite.DestinationFolder;

            if (dialog.ShowDialog() == DialogResult.OK)
            {
                Favorites favorites = new Favorites();

                LoadFavorites(favorites);

                favoriteListBox.SelectedIndex = selectedIndex;
            }
        }
    }
}
